Package: ggversa
Type: Package
Title: Conjuntos de Datos para 'Graficas Versatiles con ggplot2'
Version: 0.1.1
Authors@R: c(
    person("Raymond L.", "Tremblay", , "raymondtremblay1@mac.com",
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-8588-4372")),
    person("Julian", "Hernandez-Serrano", role = "aut")
    )
Description: Una coleccion de conjuntos de datos para el libro
    "Graficas versatiles con ggplot: Analisis visuales de datos",
    por Raymond L. Tremblay y Julian Hernandez-Serrano. Incluye datos
    de ecologia, salud publica, educacion, economia y biodiversidad
    para la ensenanza de visualizacion de datos con 'ggplot2'.
License: GPL (>= 2)
Language: es
Encoding: UTF-8
LazyData: true
LazyDataCompression: xz
Depends: R (>= 3.5.0)
Suggests: ggplot2, reshape2
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-05-07 17:53:46 UTC; raymondtremblay
Author: Raymond L. Tremblay [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-8588-4372>),
  Julian Hernandez-Serrano [aut]
Maintainer: Raymond L. Tremblay <raymondtremblay1@mac.com>
Repository: CRAN
Date/Publication: 2026-05-07 19:01:58 UTC
Built: R 4.5.2; ; 2026-05-07 21:02:15 UTC; unix
