#' Matrícula de Niñas en Educación Preprimaria y Primaria
#'
#' Datos de matrícula de niñas en educación preprimaria (NMPP) y educación primaria
#' (PMEP) por país durante el período 2010-2014. Los porcentajes representan la
#' matrícula neta de niñas en estos niveles educativos.
#'
#' @docType data
#'
#' @usage data(Educacion_Ninas)
#'
#' @format Un data frame con 24 filas y 13 columnas:
#' \describe{
#'   \item{Serie}{Nombre de la serie de datos para educación preprimaria (NMPP). Carácter.}
#'   \item{X2010NMPP}{Porcentaje de matrícula neta de niñas en educación preprimaria para el año 2010. Numérico (doble).}
#'   \item{X2011NMPP}{Porcentaje de matrícula neta de niñas en educación preprimaria para el año 2011. Numérico (doble).}
#'   \item{X2012NMPP}{Porcentaje de matrícula neta de niñas en educación preprimaria para el año 2012. Numérico (doble).}
#'   \item{X2013NMPP}{Porcentaje de matrícula neta de niñas en educación preprimaria para el año 2013. Numérico (doble).}
#'   \item{X2014NMPP}{Porcentaje de matrícula neta de niñas en educación preprimaria para el año 2014. Numérico (doble).}
#'   \item{Pais}{Nombre del país. Carácter.}
#'   \item{Serie2}{Nombre de la serie de datos para educación primaria (PMEP). Carácter.}
#'   \item{X2010PMEP}{Porcentaje de matrícula neta de niñas en educación primaria para el año 2010. Numérico (doble).}
#'   \item{X2011PMEP}{Porcentaje de matrícula neta de niñas en educación primaria para el año 2011. Numérico (doble).}
#'   \item{X2012PMEP}{Porcentaje de matrícula neta de niñas en educación primaria para el año 2012. Numérico (doble).}
#'   \item{X2013PMEP}{Porcentaje de matrícula neta de niñas en educación primaria para el año 2013. Numérico (doble).}
#'   \item{X2014PMEP}{Porcentaje de matrícula neta de niñas en educación primaria para el año 2014. Numérico (doble).}
#' }
#'
#' @source Banco Mundial / UNESCO. Indicadores de Desarrollo Mundial.
#' Matriculacion en educacion pre-primaria y primaria.
#' \url{https://data.worldbank.org/indicator/SE.PRM.NENR}
#'
#' @examples
#' data(Educacion_Ninas)
#' head(Educacion_Ninas)
#' library(ggplot2)
#' ggplot(Educacion_Ninas, aes(x = X2010PMEP, y = X2014PMEP)) +
#'   geom_point() +
#'   theme_minimal()
#'
#' @keywords datasets
#'
"Educacion_Ninas"
