#' Producto Interno Bruto versus Alfabetismo en América Latina
#'
#' Datos que relacionan el producto interno bruto (PIB) dedicado a educación
#' con los niveles de alfabetismo en 20 países de América Latina.
#'
#' @format Un data frame con 20 filas y 3 columnas:
#' \describe{
#'   \item{Pais}{character: nombre del país de América Latina}
#'   \item{Alfabetismo}{numeric: porcentaje de alfabetismo (\%)}
#'   \item{Porciento_PIB}{numeric: porcentaje del PIB dedicado a educación (\%)}
#' }
#'
#' @source Banco Mundial. Indicadores de Desarrollo Mundial.
#' PIB per capita y tasa de alfabetismo (SE.ADT.LITR.ZS).
#' \url{https://data.worldbank.org/}
#'
#' @docType data
#'
#' @usage data(PIB_vs_Alfabetismo)
#'
#' @keywords datasets
#'
#' @examples
#' head(PIB_vs_Alfabetismo)
#'
"PIB_vs_Alfabetismo"
