#' Producto Interno Bruto en Salud versus Esperanza de Vida
#'
#' Datos que relacionan el gasto en salud como porcentaje del producto interno bruto (PIB)
#' con la esperanza de vida al nacer en 20 países.
#'
#' @format Un data frame con 20 filas y 3 columnas:
#' \describe{
#'   \item{Pais}{character: nombre del país}
#'   \item{Porcentaje_PIB_Salud}{numeric: porcentaje del gasto público en salud respecto al PIB (\%)}
#'   \item{Esperanza_vida}{numeric: esperanza de vida al nacer (años)}
#' }
#'
#' @source globalEDGE, Michigan State University.
#' Indicadores de gasto en salud y esperanza de vida.
#' \url{https://globaledge.msu.edu/}
#'
#' @docType data
#'
#' @usage data(PIB_vs_Salud)
#'
#' @keywords datasets
#'
#' @examples
#' head(PIB_vs_Salud)
#'
"PIB_vs_Salud"
